==> q3-ui-filemanager-3.8.0.tgz: package/lib/DirectoryView/DirectoryView.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _q3UiHelpers = require("q3-ui-helpers");

var _DirectoryView = _interopRequireDefault(require("./DirectoryView"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const checkComponentDisplayName = (stateValue, displayName) => {
  jest.spyOn(_react.default, 'useState').mockReturnValue([stateValue, jest.fn()]);
  global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, Element => {
    const {
      type
    } = /*#__PURE__*/_react.default.createElement(Element, null);

    expect(type.displayName).toMatch(displayName);
    return null;
  }));
};

describe('DirectoryView', () => {
  it('should call local storage', () => {
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi');
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, () => null));
    expect(spy).toHaveBeenCalledWith('getItem', 'q3-filemanager-view');
  });
  it('should change view', () => {
    const setState = jest.fn();
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi');
    jest.spyOn(_react.default, 'useState').mockReturnValue(['list', setState]);
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, (_, Component) => {
      Component().props.onChange(null, 'gallery');
      return null;
    }));
    expect(setState).toHaveBeenCalledWith('gallery');
    expect(spy).toHaveBeenCalledWith('setItem', 'q3-filemanager-view', 'gallery');
  });
  it('should render list', () => {
    checkComponentDisplayName('list', 'list');
    checkComponentDisplayName('unknown', 'list');
  });
  it('should render gallery', () => {
    checkComponentDisplayName('gallery', 'gallery');
  });
});

==> q3-ui-filemanager-3.13.0.tgz: package/lib/DirectoryView/DirectoryView.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _q3UiHelpers = require("q3-ui-helpers");

var _DirectoryView = _interopRequireDefault(require("./DirectoryView"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const checkComponentDisplayName = (stateValue, displayName) => {
  jest.spyOn(_react.default, 'useState').mockReturnValue([stateValue, jest.fn()]);
  global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, Element => {
    const {
      type
    } = /*#__PURE__*/_react.default.createElement(Element, null);

    expect(type.displayName).toMatch(displayName);
    return null;
  }));
};

describe('DirectoryView', () => {
  it('should call local storage', () => {
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi');
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, () => null));
    expect(spy).toHaveBeenCalledWith('getItem', 'q3-filemanager-view');
  });
  it('should change view', () => {
    const setState = jest.fn();
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi');
    jest.spyOn(_react.default, 'useState').mockReturnValue(['list', setState]);
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectoryView.default, null, (_, Component) => {
      Component().props.onClick();
      return null;
    }));
    expect(setState).toHaveBeenCalledWith('gallery');
    expect(spy).toHaveBeenCalledWith('setItem', 'q3-filemanager-view', 'gallery');
  });
  it('should render list', () => {
    checkComponentDisplayName('list', 'list');
    checkComponentDisplayName('unknown', 'list');
  });
  it('should render gallery', () => {
    checkComponentDisplayName('gallery', 'gallery');
  });
});
